#[derive(Cast)]
Derive macro generating an impl of trait Cast for a struct type or a union type.
Cast
struct
union
It must be applied together with attribute #[repr(C)].
#[
repr(C)
]
For detailed information, see the document of trait Cast.